@@ -1,23 +1,21 @@
 require 'spec_helper_acceptance'
-require 'puppet'
 require 'puppet/util/package'
 require_relative '../mysql_helper.rb'
 
 describe 'mysql_grant' do
   before(:all) do
-    pp = <<-EOS
+    pp = <<-MANIFEST
       class { 'mysql::server':
         root_password => 'password',
       }
-    EOS
+    MANIFEST
 
-    apply_manifest(pp, :catch_failures => true)
+    apply_manifest(pp, catch_failures: true)
   end
 
   describe 'missing privileges for user' do
-    it 'should fail' do
-      pp = <<-EOS
-        mysql_user { 'test1@tester': 
+    pp = <<-MANIFEST
+        mysql_user { 'test1@tester':
           ensure => present,
         }
         mysql_grant { 'test1@tester/test.*':
@@ -26,19 +24,18 @@ describe 'mysql_grant' do
           user    => 'test1@tester',
           require => Mysql_user['test1@tester'],
         }
-      EOS
-
-      expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/privileges parameter is required/)
+    MANIFEST
+    it 'fails' do
+      expect(apply_manifest(pp, expect_failures: true).stderr).to match(%r{`privileges` `parameter` is required})
     end
 
-    it 'should not find the user' do
-      expect(shell("mysql -NBe \"SHOW GRANTS FOR test1@tester\"", { :acceptable_exit_codes => 1}).stderr).to match(/There is no such grant defined for user 'test1' on host 'tester'/)
+    it 'does not find the user' do
+      expect(shell('mysql -NBe "SHOW GRANTS FOR test1@tester"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'test1' on host 'tester'})
     end
   end
 
   describe 'missing table for user' do
-    it 'should fail' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'atest@tester':
           ensure => present,
         }
@@ -48,19 +45,18 @@ describe 'mysql_grant' do
           privileges => ['ALL'],
           require    => Mysql_user['atest@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :expect_failures => true)
+    MANIFEST
+    it 'fails' do
+      apply_manifest(pp, expect_failures: true)
     end
 
-    it 'should not find the user' do
-      expect(shell("mysql -NBe \"SHOW GRANTS FOR atest@tester\"", {:acceptable_exit_codes => 1}).stderr).to match(/There is no such grant defined for user 'atest' on host 'tester'/)
+    it 'does not find the user' do
+      expect(shell('mysql -NBe "SHOW GRANTS FOR atest@tester"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'atest' on host 'tester'})
     end
   end
 
   describe 'adding privileges' do
-    it 'should work without errors' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test2@tester':
           ensure => present,
         }
@@ -71,22 +67,25 @@ describe 'mysql_grant' do
           privileges => ['SELECT', 'UPDATE'],
           require    => Mysql_user['test2@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'works without errors' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'should find the user' do
-      shell("mysql -NBe \"SHOW GRANTS FOR test2@tester\"") do |r|
-        expect(r.stdout).to match(/GRANT SELECT, UPDATE.*TO 'test2'@'tester'/)
+    it 'finds the user #stdout' do
+      shell('mysql -NBe "SHOW GRANTS FOR test2@tester"') do |r|
+        expect(r.stdout).to match(%r{GRANT SELECT, UPDATE.*TO 'test2'@'tester'})
+      end
+    end
+    it 'finds the user #stderr' do
+      shell('mysql -NBe "SHOW GRANTS FOR test2@tester"') do |r|
         expect(r.stderr).to be_empty
       end
     end
   end
 
   describe 'adding privileges with special character in name' do
-    it 'should work without errors' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test-2@tester':
           ensure => present,
         }
@@ -97,41 +96,25 @@ describe 'mysql_grant' do
           privileges => ['SELECT', 'UPDATE'],
           require    => Mysql_user['test-2@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'works without errors' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'should find the user' do
+    it 'finds the user #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test-2'@tester\"") do |r|
+        expect(r.stdout).to match(%r{GRANT SELECT, UPDATE.*TO 'test-2'@'tester'})
+      end
+    end
+    it 'finds the user #stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test-2'@tester\"") do |r|
-        expect(r.stdout).to match(/GRANT SELECT, UPDATE.*TO 'test-2'@'tester'/)
         expect(r.stderr).to be_empty
       end
     end
   end
 
-  describe 'adding privileges with invalid name' do
-    it 'should fail' do
-      pp = <<-EOS
-        mysql_user { 'test2@tester':
-          ensure => present,
-        }
-        mysql_grant { 'test':
-          ensure     => 'present',
-          table      => 'test.*',
-          user       => 'test2@tester',
-          privileges => ['SELECT', 'UPDATE'],
-          require    => Mysql_user['test2@tester'],
-        }
-      EOS
-
-      expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/name must match user and table parameters/)
-    end
-  end
-
   describe 'adding option' do
-    it 'should work without errors' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test3@tester':
           ensure => present,
         }
@@ -143,22 +126,25 @@ describe 'mysql_grant' do
           privileges => ['SELECT', 'UPDATE'],
           require    => Mysql_user['test3@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'works without errors' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'should find the user' do
-      shell("mysql -NBe \"SHOW GRANTS FOR test3@tester\"") do |r|
-        expect(r.stdout).to match(/GRANT SELECT, UPDATE ON `test`.* TO 'test3'@'tester' WITH GRANT OPTION$/)
+    it 'finds the user #stdout' do
+      shell('mysql -NBe "SHOW GRANTS FOR test3@tester"') do |r|
+        expect(r.stdout).to match(%r{GRANT SELECT, UPDATE ON `test`.* TO 'test3'@'tester' WITH GRANT OPTION$})
+      end
+    end
+    it 'finds the user #stderr' do
+      shell('mysql -NBe "SHOW GRANTS FOR test3@tester"') do |r|
         expect(r.stderr).to be_empty
       end
     end
   end
 
   describe 'adding all privileges without table' do
-    it 'should fail' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test4@tester':
           ensure => present,
         }
@@ -169,15 +155,14 @@ describe 'mysql_grant' do
           privileges => ['SELECT', 'UPDATE', 'ALL'],
           require    => Mysql_user['test4@tester'],
         }
-      EOS
-
-      expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/table parameter is required./)
+    MANIFEST
+    it 'fails' do
+      expect(apply_manifest(pp, expect_failures: true).stderr).to match(%r{`table` `parameter` is required.})
     end
   end
 
   describe 'adding all privileges' do
-    it 'should only try to apply ALL' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test4@tester':
           ensure => present,
         }
@@ -189,14 +174,18 @@ describe 'mysql_grant' do
           privileges => ['SELECT', 'UPDATE', 'ALL'],
           require    => Mysql_user['test4@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'onlies try to apply ALL' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'should find the user' do
-      shell("mysql -NBe \"SHOW GRANTS FOR test4@tester\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test4'@'tester' WITH GRANT OPTION/)
+    it 'finds the user #stdout' do
+      shell('mysql -NBe "SHOW GRANTS FOR test4@tester"') do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test4'@'tester' WITH GRANT OPTION})
+      end
+    end
+    it 'finds the user #stderr' do
+      shell('mysql -NBe "SHOW GRANTS FOR test4@tester"') do |r|
         expect(r.stderr).to be_empty
       end
     end
@@ -204,8 +193,7 @@ describe 'mysql_grant' do
 
   # Test combinations of user@host to ensure all cases work.
   describe 'short hostname' do
-    it 'should apply' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         mysql_user { 'test@short':
           ensure => present,
         }
@@ -256,46 +244,69 @@ describe 'mysql_grant' do
           privileges => 'ALL',
           require    => Mysql_user['test@::1/128'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'applies' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'finds short hostname' do
-      shell("mysql -NBe \"SHOW GRANTS FOR test@short\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'short'/)
+    it 'finds short hostname #stdout' do
+      shell('mysql -NBe "SHOW GRANTS FOR test@short"') do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'short'})
+      end
+    end
+    it 'finds short hostname #stderr' do
+      shell('mysql -NBe "SHOW GRANTS FOR test@short"') do |r|
         expect(r.stderr).to be_empty
       end
     end
-    it 'finds long hostname' do
+
+    it 'finds long hostname #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'long.hostname.com'\"") do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'long.hostname.com'})
+      end
+    end
+    it 'finds long hostname #stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'long.hostname.com'\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'long.hostname.com'/)
         expect(r.stderr).to be_empty
       end
     end
-    it 'finds ipv4' do
+
+    it 'finds ipv4 #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'192.168.5.6'\"") do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'192.168.5.6'})
+      end
+    end
+    it 'finds ipv4 #stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'192.168.5.6'\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'192.168.5.6'/)
         expect(r.stderr).to be_empty
       end
     end
-    it 'finds ipv6' do
+
+    it 'finds ipv6 #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'2607:f0d0:1002:0051:0000:0000:0000:0004'\"") do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'2607:f0d0:1002:0051:0000:0000:0000:0004'})
+      end
+    end
+    it 'finds ipv6 #stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'2607:f0d0:1002:0051:0000:0000:0000:0004'\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'2607:f0d0:1002:0051:0000:0000:0000:0004'/)
         expect(r.stderr).to be_empty
       end
     end
-    it 'finds short ipv6' do
+
+    it 'finds short ipv6 #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'::1/128'\"") do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'::1\/128'})
+      end
+    end
+    it 'finds short ipv6 @stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'::1/128'\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'::1\/128'/)
         expect(r.stderr).to be_empty
       end
     end
   end
 
   describe 'complex test' do
-    it 'setup mysql::server' do
-      pp = <<-EOS
+    pp = <<-MANIFEST
         $dbSubnet = '10.10.10.%'
 
         mysql_database { 'foo':
@@ -370,16 +381,15 @@ describe 'mysql_grant' do
           user       => 'web@localhost',
           require    => Mysql_user['web@localhost'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
-      apply_manifest(pp, :catch_changes => true)
+    MANIFEST
+    it 'setup mysql::server' do
+      apply_manifest(pp, catch_failures: true)
+      apply_manifest(pp, catch_changes: true)
     end
   end
 
   describe 'lower case privileges' do
-    it 'create ALL privs' do
-      pp = <<-EOS
+    pp_one = <<-MANIFEST
         mysql_user { 'lowercase@localhost':
           ensure => present,
         }
@@ -389,13 +399,12 @@ describe 'mysql_grant' do
           table      => '*.*',
           require    => Mysql_user['lowercase@localhost'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'create ALL privs' do
+      apply_manifest(pp_one, catch_failures: true)
     end
 
-    it 'create lowercase all privs' do
-      pp = <<-EOS
+    pp_two = <<-MANIFEST
         mysql_user { 'lowercase@localhost':
           ensure => present,
         }
@@ -405,21 +414,18 @@ describe 'mysql_grant' do
           table      => '*.*',
           require    => Mysql_user['lowercase@localhost'],
         }
-      EOS
-
-      expect(apply_manifest(pp, :catch_failures => true).exit_code).to eq(0)
+    MANIFEST
+    it 'create lowercase all privs' do
+      expect(apply_manifest(pp_two, catch_failures: true).exit_code).to eq(0)
     end
   end
 
   describe 'adding procedure privileges' do
-    it 'should work without errors' do
-      pp = <<-EOS
-        if $::operatingsystem == 'Ubuntu' and versioncmp($::operatingsystemmajrelease, '16.00') > 0 {
-          exec { 'simpleproc-create':
-            command => 'mysql --user="root" --password="password" --database=mysql --delimiter="//" -NBe "CREATE PROCEDURE simpleproc (OUT param1 INT) BEGIN SELECT COUNT(*) INTO param1 FROM t; end//"',
-            path    => '/usr/bin/',
-            before  => Mysql_user['test2@tester'],
-          }
+    pp = <<-MANIFEST
+        exec { 'simpleproc-create':
+          command => 'mysql --user="root" --password="password" --database=mysql --delimiter="//" -NBe "CREATE PROCEDURE simpleproc (OUT param1 INT) BEGIN SELECT COUNT(*) INTO param1 FROM t; end//"',
+          path    => '/usr/bin/',
+          before  => Mysql_user['test2@tester'],
         }
         mysql_user { 'test2@tester':
           ensure => present,
@@ -431,35 +437,198 @@ describe 'mysql_grant' do
           privileges => ['EXECUTE'],
           require    => Mysql_user['test2@tester'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'works without errors' do
+      apply_manifest(pp, catch_failures: true)
     end
 
-    it 'should find the user' do
-      shell("mysql -NBe \"SHOW GRANTS FOR test2@tester\"") do |r|
-        expect(r.stdout).to match(/GRANT EXECUTE ON PROCEDURE `mysql`.`simpleproc` TO 'test2'@'tester'/)
+    it 'finds the user #stdout' do
+      shell('mysql -NBe "SHOW GRANTS FOR test2@tester"') do |r|
+        expect(r.stdout).to match(%r{GRANT EXECUTE ON PROCEDURE `mysql`.`simpleproc` TO 'test2'@'tester'})
+      end
+    end
+    it 'finds the user #stderr' do
+      shell('mysql -NBe "SHOW GRANTS FOR test2@tester"') do |r|
         expect(r.stderr).to be_empty
       end
     end
   end
 
-  describe 'grants with skip-name-resolve specified' do
-    it 'setup mysql::server' do
+  describe 'adding function privileges' do
+    it 'works without errors' do
       pp = <<-EOS
+        exec { 'simplefunc-create':
+          command => '/usr/bin/mysql --user="root" --password="password" --database=mysql -NBe "CREATE FUNCTION simplefunc (s CHAR(20)) RETURNS CHAR(50) DETERMINISTIC RETURN CONCAT(\\'Hello, \\', s, \\'!\\')"',
+          before  => Mysql_user['test3@tester'],
+        }
+
+        mysql_user { 'test3@tester':
+          ensure => 'present',
+        }
+
+        mysql_grant { 'test3@tester/FUNCTION mysql.simplefunc':
+          ensure     => 'present',
+          table      => 'FUNCTION mysql.simplefunc',
+          user       => 'test3@tester',
+          privileges => ['EXECUTE'],
+          require    => Mysql_user['test3@tester'],
+        }
+      EOS
+
+      apply_manifest(pp, catch_failures: true)
+    end
+    # rubocop:enable RSpec/ExampleLength
+    it 'finds the user' do
+      shell('mysql -NBe "SHOW GRANTS FOR test3@tester"') do |r|
+        expect(r.stdout).to match(%r{GRANT EXECUTE ON FUNCTION `mysql`.`simplefunc` TO 'test3'@'tester'})
+        expect(r.stderr).to be_empty
+      end
+    end
+    # rubocop:enable RSpec/MultipleExpectations
+  end
+
+  describe 'proxy privilieges' do
+    pre_run
+
+    describe 'adding proxy privileges', if: version_is_greater_than('5.5.0') do
+      pp = <<-MANIFEST
+        mysql_user { 'proxy1@tester':
+          ensure => present,
+        }
+        mysql_grant { 'proxy1@tester/proxy_user@proxy_host':
+          ensure     => 'present',
+          table      => 'proxy_user@proxy_host',
+          user       => 'proxy1@tester',
+          privileges => ['PROXY'],
+          require    => Mysql_user['proxy1@tester'],
+        }
+      MANIFEST
+      it 'works without errors when version greater than 5.5.0' do
+        apply_manifest(pp, catch_failures: true)
+      end
+
+      it 'finds the user #stdout' do
+        shell('mysql -NBe "SHOW GRANTS FOR proxy1@tester"') do |r|
+          expect(r.stdout).to match(%r{GRANT PROXY ON 'proxy_user'@'proxy_host' TO 'proxy1'@'tester'})
+        end
+      end
+      it 'finds the user #stderr' do
+        shell('mysql -NBe "SHOW GRANTS FOR proxy1@tester"') do |r|
+          expect(r.stderr).to be_empty
+        end
+      end
+    end
+
+    describe 'removing proxy privileges', if: version_is_greater_than('5.5.0') do
+      pp = <<-MANIFEST
+        mysql_user { 'proxy1@tester':
+          ensure => present,
+        }
+        mysql_grant { 'proxy1@tester/proxy_user@proxy_host':
+          ensure     => 'absent',
+          table      => 'proxy_user@proxy_host',
+          user       => 'proxy1@tester',
+          privileges => ['PROXY'],
+          require    => Mysql_user['proxy1@tester'],
+        }
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp, catch_failures: true)
+      end
+
+      it 'finds the user #stdout' do
+        shell('mysql -NBe "SHOW GRANTS FOR proxy1@tester"') do |r|
+          expect(r.stdout).not_to match(%r{GRANT PROXY ON 'proxy_user'@'proxy_host' TO 'proxy1'@'tester'})
+        end
+      end
+      it 'finds the user #stderr' do
+        shell('mysql -NBe "SHOW GRANTS FOR proxy1@tester"') do |r|
+          expect(r.stderr).to be_empty
+        end
+      end
+    end
+
+    describe 'adding proxy privileges with other privileges', if: version_is_greater_than('5.5.0') do
+      pp = <<-MANIFEST
+        mysql_user { 'proxy2@tester':
+          ensure => present,
+        }
+        mysql_grant { 'proxy2@tester/proxy_user@proxy_host':
+          ensure     => 'present',
+          table      => 'proxy_user@proxy_host',
+          user       => 'proxy2@tester',
+          privileges => ['PROXY', 'SELECT'],
+          require    => Mysql_user['proxy2@tester'],
+        }
+      MANIFEST
+      it 'fails' do
+        expect(apply_manifest(pp, expect_failures: true).stderr).to match(%r{`privileges` `parameter`: PROXY can only be specified by itself})
+      end
+
+      it 'does not find the user' do
+        expect(shell('mysql -NBe "SHOW GRANTS FOR proxy2@tester"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'proxy2' on host 'tester'})
+      end
+    end
+
+    describe 'adding proxy privileges with mysql version less than 5.5.0', unless: version_is_greater_than('5.5.0') do
+      pp = <<-MANIFEST
+        mysql_user { 'proxy3@tester':
+          ensure => present,
+        }
+        mysql_grant { 'proxy3@tester/proxy_user@proxy_host':
+          ensure     => 'present',
+          table      => 'proxy_user@proxy_host',
+          user       => 'proxy3@tester',
+          privileges => ['PROXY', 'SELECT'],
+          require    => Mysql_user['proxy3@tester'],
+        }
+      MANIFEST
+      it 'fails' do
+        expect(apply_manifest(pp, expect_failures: true).stderr).to match(%r{PROXY user not supported on mysql versions < 5\.5\.0}i)
+      end
+
+      it 'does not find the user' do
+        expect(shell('mysql -NBe "SHOW GRANTS FOR proxy2@tester"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'proxy2' on host 'tester'})
+      end
+    end
+
+    describe 'adding proxy privileges with invalid proxy user', if: version_is_greater_than('5.5.0') do
+      pp = <<-MANIFEST
+        mysql_user { 'proxy3@tester':
+          ensure => present,
+        }
+        mysql_grant { 'proxy3@tester/invalid_proxy_user':
+          ensure     => 'present',
+          table      => 'invalid_proxy_user',
+          user       => 'proxy3@tester',
+          privileges => ['PROXY'],
+          require    => Mysql_user['proxy3@tester'],
+        }
+      MANIFEST
+      it 'fails' do
+        expect(apply_manifest(pp, expect_failures: true).stderr).to match(%r{`table` `property` for PROXY should be specified as proxy_user@proxy_host.})
+      end
+
+      it 'does not find the user' do
+        expect(shell('mysql -NBe "SHOW GRANTS FOR proxy3@tester"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'proxy3' on host 'tester'})
+      end
+    end
+  end
+
+  describe 'grants with skip-name-resolve specified' do
+    pp_one = <<-MANIFEST
         class { 'mysql::server':
           override_options => {
             'mysqld' => {'skip-name-resolve' => true}
           },
           restart          => true,
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'setup mysql::server' do
+      apply_manifest(pp_one, catch_failures: true)
     end
 
-    it 'should apply' do
-      pp = <<-EOS
+    pp_two = <<-MANIFEST
         mysql_user { 'test@fqdn.com':
           ensure => present,
         }
@@ -480,26 +649,30 @@ describe 'mysql_grant' do
           privileges => 'ALL',
           require    => Mysql_user['test@192.168.5.7'],
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'applies' do
+      apply_manifest(pp_two, catch_failures: true)
     end
 
-    it 'should fail with fqdn' do
+    it 'fails with fqdn' do
       pre_run
-      if ! version_is_greater_than('5.7.0')
-        expect(shell("mysql -NBe \"SHOW GRANTS FOR test@fqdn.com\"", { :acceptable_exit_codes => 1}).stderr).to match(/There is no such grant defined for user 'test' on host 'fqdn.com'/)
+      unless version_is_greater_than('5.7.0')
+        expect(shell('mysql -NBe "SHOW GRANTS FOR test@fqdn.com"', acceptable_exit_codes: 1).stderr).to match(%r{There is no such grant defined for user 'test' on host 'fqdn.com'})
       end
     end
-    it 'finds ipv4' do
+
+    it 'finds ipv4 #stdout' do
+      shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'192.168.5.7'\"") do |r|
+        expect(r.stdout).to match(%r{GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'192.168.5.7'})
+      end
+    end
+    it 'finds ipv4 #stderr' do
       shell("mysql -NBe \"SHOW GRANTS FOR 'test'@'192.168.5.7'\"") do |r|
-        expect(r.stdout).to match(/GRANT ALL PRIVILEGES ON `test`.* TO 'test'@'192.168.5.7'/)
         expect(r.stderr).to be_empty
       end
     end
 
-    it 'should fail to execute while applying' do
-      pp = <<-EOS
+    pp_three = <<-MANIFEST
         mysql_user { 'test@fqdn.com':
           ensure => present,
         }
@@ -510,37 +683,34 @@ describe 'mysql_grant' do
           privileges => 'ALL',
           require    => Mysql_user['test@fqdn.com'],
         }
-      EOS
-
+    MANIFEST
+    it 'fails to execute while applying' do
       mysql_cmd = shell('which mysql').stdout.chomp
       shell("mv #{mysql_cmd} #{mysql_cmd}.bak")
-      expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/Command mysql is missing/)
+      expect(apply_manifest(pp_three, expect_failures: true).stderr).to match(%r{Could not find a suitable provider for mysql_grant})
       shell("mv #{mysql_cmd}.bak #{mysql_cmd}")
     end
 
-    it 'reset mysql::server config' do
-      pp = <<-EOS
+    pp_four = <<-MANIFEST
         class { 'mysql::server':
           restart          => true,
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'reset mysql::server config' do
+      apply_manifest(pp_four, catch_failures: true)
     end
   end
 
   describe 'adding privileges to specific table' do
     # Using puppet_apply as a helper
-    it 'setup mysql server' do
-      pp = <<-EOS
+    pp_one = <<-MANIFEST
         class { 'mysql::server': override_options => { 'root_password' => 'password' } }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'setup mysql server' do
+      apply_manifest(pp_one, catch_failures: true)
     end
 
-    it 'creates grant on missing table will fail' do
-      pp = <<-EOS
+    pp_two = <<-MANIFEST
         mysql_user { 'test@localhost':
           ensure => present,
         }
@@ -550,12 +720,12 @@ describe 'mysql_grant' do
           table      => 'grant_spec_db.grant_spec_table',
           require    => Mysql_user['test@localhost'],
         }
-      EOS
-      expect(apply_manifest(pp, :expect_failures => true).stderr).to match(/Table 'grant_spec_db\.grant_spec_table' doesn't exist/)
+    MANIFEST
+    it 'creates grant on missing table will fail' do
+      expect(apply_manifest(pp_two, expect_failures: true).stderr).to match(%r{Table 'grant_spec_db\.grant_spec_table' doesn't exist})
     end
 
-    it 'creates table' do
-      pp = <<-EOS
+    pp_three = <<-MANIFEST
         file { '/tmp/grant_spec_table.sql':
           ensure  => file,
           content => 'CREATE TABLE grant_spec_table (id int);',
@@ -566,12 +736,12 @@ describe 'mysql_grant' do
           password => 'password',
           sql      => '/tmp/grant_spec_table.sql',
         }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'creates table' do
+      apply_manifest(pp_three, catch_failures: true)
     end
 
-    it 'should have the table' do
+    it 'has the table' do
       expect(shell("mysql -e 'show tables;' grant_spec_db|grep grant_spec_table").exit_code).to be_zero
     end
   end
