@@ -1,58 +1,103 @@
 require 'spec_helper_acceptance'
+require_relative '../mysql_helper.rb'
 
 describe 'mysql_user' do
   describe 'setup' do
-    it 'should work with no errors' do
-      pp = <<-EOS
+    pp_one = <<-MANIFEST
         class { 'mysql::server': }
-      EOS
-
-      apply_manifest(pp, :catch_failures => true)
+    MANIFEST
+    it 'works with no errors' do
+      apply_manifest(pp_one, catch_failures: true)
     end
   end
 
   context 'using ashp@localhost' do
     describe 'adding user' do
-      it 'should work without errors' do
-        pp = <<-EOS
+      pp_two = <<-MANIFEST
           mysql_user { 'ashp@localhost':
             password_hash => '*F9A8E96790775D196D12F53BCC88B8048FF62ED5',
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp_two, catch_failures: true)
       end
 
-      it 'should find the user' do
+      it 'finds the user #stdout' do
+        shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^1$})
+        end
+      end
+      it 'finds the user #stderr' do
         shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
-          expect(r.stdout).to match(/^1$/)
           expect(r.stderr).to be_empty
         end
       end
-      it 'has no SSL options' do
+
+      it 'has no SSL options #stdout' do
+        shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^\s*$})
+        end
+      end
+      it 'has no SSL options #stderr' do
         shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
-          expect(r.stdout).to match(/^\s*$/)
           expect(r.stderr).to be_empty
         end
       end
     end
+
+    pre_run
+    describe 'changing authentication plugin', if: version_is_greater_than('5.5.0') do
+      it 'works without errors' do
+        pp = <<-EOS
+          mysql_user { 'ashp@localhost':
+            plugin => 'auth_socket',
+          }
+        EOS
+
+        apply_manifest(pp, catch_failures: true)
+      end
+
+      it 'has the correct plugin' do
+        shell("mysql -NBe \"select plugin from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
+          expect(r.stdout.rstrip).to eq('auth_socket')
+          expect(r.stderr).to be_empty
+        end
+      end
+
+      it 'does not have a password' do
+        pre_run
+        table = if version_is_greater_than('5.7.0')
+                  'authentication_string'
+                else
+                  'password'
+                end
+        shell("mysql -NBe \"select #{table} from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
+          expect(r.stdout.rstrip).to be_empty
+          expect(r.stderr).to be_empty
+        end
+      end
+    end
+    # rubocop:enable RSpec/ExampleLength, RSpec/MultipleExpectations
   end
 
   context 'using ashp-dash@localhost' do
     describe 'adding user' do
-      it 'should work without errors' do
-        pp = <<-EOS
+      pp_three = <<-MANIFEST
           mysql_user { 'ashp-dash@localhost':
             password_hash => '*F9A8E96790775D196D12F53BCC88B8048FF62ED5',
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp_three, catch_failures: true)
       end
 
-      it 'should find the user' do
+      it 'finds the user #stdout' do
+        shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp-dash@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^1$})
+        end
+      end
+      it 'finds the user #stderr' do
         shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp-dash@localhost'\"") do |r|
-          expect(r.stdout).to match(/^1$/)
           expect(r.stderr).to be_empty
         end
       end
@@ -61,19 +106,22 @@ describe 'mysql_user' do
 
   context 'using ashp@LocalHost' do
     describe 'adding user' do
-      it 'should work without errors' do
-        pp = <<-EOS
+      pp_four = <<-MANIFEST
           mysql_user { 'ashp@LocalHost':
             password_hash => '*F9A8E96790775D196D12F53BCC88B8048FF62ED5',
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp_four, catch_failures: true)
       end
 
-      it 'should find the user' do
+      it 'finds the user #stdout' do
+        shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^1$})
+        end
+      end
+      it 'finds the user #stderr' do
         shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'ashp@localhost'\"") do |r|
-          expect(r.stdout).to match(/^1$/)
           expect(r.stderr).to be_empty
         end
       end
@@ -81,36 +129,48 @@ describe 'mysql_user' do
   end
   context 'using resource should throw no errors' do
     describe 'find users' do
-      it {
-        on default, puppet('resource mysql_user'), {:catch_failures => true} do |r|
-          expect(r.stdout).to_not match(/Error:/)
-          expect(r.stdout).to_not match(/must be properly quoted, invalid character:/)
+      it do
+        on default, puppet('resource mysql_user'), catch_failures: true do |r|
+          expect(r.stdout).not_to match(%r{Error:})
         end
-      }
+      end
+      it do
+        on default, puppet('resource mysql_user'), catch_failures: true do |r|
+          expect(r.stdout).not_to match(%r{must be properly quoted, invalid character:})
+        end
+      end
     end
   end
   context 'using user-w-ssl@localhost with SSL' do
     describe 'adding user' do
-      it 'should work without errors' do
-        pp = <<-EOS
+      pp_five = <<-MANIFEST
           mysql_user { 'user-w-ssl@localhost':
             password_hash => '*F9A8E96790775D196D12F53BCC88B8048FF62ED5',
             tls_options   => ['SSL'],
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp_five, catch_failures: true)
       end
 
-      it 'should find the user' do
+      it 'finds the user #stdout' do
+        shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'user-w-ssl@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^1$})
+        end
+      end
+      it 'finds the user #stderr' do
         shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'user-w-ssl@localhost'\"") do |r|
-          expect(r.stdout).to match(/^1$/)
           expect(r.stderr).to be_empty
         end
       end
-      it 'should show correct ssl_type' do
+
+      it 'shows correct ssl_type #stdout' do
+        shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'user-w-ssl@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^ANY$})
+        end
+      end
+      it 'shows correct ssl_type #stderr' do
         shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'user-w-ssl@localhost'\"") do |r|
-          expect(r.stdout).to match(/^ANY$/)
           expect(r.stderr).to be_empty
         end
       end
@@ -118,26 +178,34 @@ describe 'mysql_user' do
   end
   context 'using user-w-x509@localhost with X509' do
     describe 'adding user' do
-      it 'should work without errors' do
-        pp = <<-EOS
+      pp_six = <<-MANIFEST
           mysql_user { 'user-w-x509@localhost':
             password_hash => '*F9A8E96790775D196D12F53BCC88B8048FF62ED5',
             tls_options   => ['X509'],
           }
-        EOS
-
-        apply_manifest(pp, :catch_failures => true)
+      MANIFEST
+      it 'works without errors' do
+        apply_manifest(pp_six, catch_failures: true)
       end
 
-      it 'should find the user' do
+      it 'finds the user #stdout' do
+        shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'user-w-x509@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^1$})
+        end
+      end
+      it 'finds the user #stderr' do
         shell("mysql -NBe \"select '1' from mysql.user where CONCAT(user, '@', host) = 'user-w-x509@localhost'\"") do |r|
-          expect(r.stdout).to match(/^1$/)
           expect(r.stderr).to be_empty
         end
       end
-      it 'should show correct ssl_type' do
+
+      it 'shows correct ssl_type #stdout' do
+        shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'user-w-x509@localhost'\"") do |r|
+          expect(r.stdout).to match(%r{^X509$})
+        end
+      end
+      it 'shows correct ssl_type #stderr' do
         shell("mysql -NBe \"select SSL_TYPE from mysql.user where CONCAT(user, '@', host) = 'user-w-x509@localhost'\"") do |r|
-          expect(r.stdout).to match(/^X509$/)
           expect(r.stderr).to be_empty
         end
       end
